@@ -34,6 +34,9 @@ CHANNEL_HORIZONTAL = """
 
 DOT_FONT_EDGE = 'fontname="times-italic" fontsize=10'
 DOT_FONT_NODE = 'fontname="helvetica" fontsize=10'
+DOT_FONT_GRAPH = 'fontname="helvetica" fontsize=9 fontcolor="#000060"'
+
+DOT_GRAPH_TITLE = """graph[label="\n- {title} -" """ + DOT_FONT_GRAPH + """]"""
 
 DOT = """
 digraph D {{
@@ -46,3 +49,6 @@ digraph D {{
 
 
 GRAPH_PARAMS_CONTEXT_DIAGRAM = 'edge [len=2.25]'
+
+
+ITEM_EXTERNAL_ATTRS = 'fillcolor=white color=grey fontcolor=grey'
\ No newline at end of file
