@@ -4,6 +4,8 @@ import subprocess
 import sys
 
 from . import model
+from .error import print_error
+
 
 def generate_image(graph_options: model.GraphOptions,
                    text: str, output_path: str, format: str) -> None:
@@ -13,7 +15,13 @@ def generate_image(graph_options: model.GraphOptions,
         engine = 'dot'
 
     cmd = [engine, f'-T{format}',  f'-o{output_path}']
-    subprocess.run(cmd, input=text, encoding='utf-8')
+    try:
+        subprocess.run(cmd, input=text, encoding='utf-8', check=True)
+    except subprocess.CalledProcessError as e:
+        for n, line in enumerate(text.splitlines()):
+            print(f'{n+1:2}: {line}', file=sys.stderr)
+        print_error(f'ERROR: {e}')
+        sys.exit(1)
     #print('Generated:', output_path, file=sys.stderr)
 
 
