@@ -66,6 +66,11 @@ class Connection(Drawable):
     relaxed: bool = False
 
 
+@dataclass
+class Frame(Drawable):
+    items: list[str]
+
+
 @dataclass
 class Style(Statement):
     style: str
@@ -87,6 +92,8 @@ CFLOW   = 'cflow'
 UFLOW   = 'uflow'
 SIGNAL  = 'signal'
 
+FRAME   = 'frame'
+
 
 @dataclass
 class GraphOptions:
